# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

Types of changes: Added, Changed, Deprecated, Removed, Fixed, Security

## [Unreleased]


## [0.2.3] - 2024-04-01

### Changed

- The method 'db.AMPODatabase.get_db' is not longer a 'classmethod'

### Added

- The Method 'delete'


## [0.2.2] - 2024-02-17

### Added
- Set version from tag


## [0.2.1] - 2024-02-17

### Added

- The 'update_expiration_value' method has been added for worker.
- Was changed behavior for TTL index.


## [0.2.0] - 2023-11-01

### Added

- Option ORMConfig.orm_bson_codec_options - This options will apply on the collection every time, when the collection is returned


## [0.0.0] - [date] - Example

### Removed
### Changed
### Fixed
### Added